// Copyright (c) Edgeless Systems GmbH.
//
// This Source Code Form is subject to the terms of the Mozilla Public
// License, v. 2.0. If a copy of the MPL was not distributed with this
// file, You can obtain one at https://mozilla.org/MPL/2.0/.

package cli

import (
	"os"
	"os/exec"
	"path/filepath"
)

// Env runs a command in the EGo environment.
func (c *Cli) Env(filename string, args []string) int {
	if filename == "go" {
		// "ego env go" should resolve to our Go compiler
		filename = filepath.Join(c.egoPath, "go", "bin", "go")
	}
	cmd := exec.Command(filename, args...)
	cmd.Env = append(os.Environ(),
		"CGO_ENABLED=1",
		"PATH="+filepath.Join(c.egoPath, "go", "bin")+":"+os.Getenv("PATH"),
		"GOROOT="+filepath.Join(c.egoPath, "go"))

	cmd.Stdin = os.Stdin
	cmd.Stdout = os.Stdout
	cmd.Stderr = os.Stderr

	if err := c.runner.Run(cmd); err != nil {
		if _, ok := err.(*exec.ExitError); !ok {
			panic(err)
		}
	}

	return c.runner.ExitCode(cmd)
}
